@@ -1,6 +1,7 @@
 import datetime
 import logging
 from string import Template
+from urllib.parse import urlparse
 
 from great_expectations.core.batch import Batch
 from great_expectations.core.util import nested_update
@@ -22,6 +23,24 @@ except ImportError:
     logger.debug("Unable to import sqlalchemy.")
 
 
+if sqlalchemy != None:
+    try:
+        import google.auth
+
+        datasource_initialization_exceptions = (
+            sqlalchemy.exc.OperationalError,
+            sqlalchemy.exc.DatabaseError,
+            sqlalchemy.exc.ArgumentError,
+            google.auth.exceptions.GoogleAuthError,
+        )
+    except ImportError:
+        datasource_initialization_exceptions = (
+            sqlalchemy.exc.OperationalError,
+            sqlalchemy.exc.DatabaseError,
+            sqlalchemy.exc.ArgumentError,
+        )
+
+
 class SqlAlchemyDatasource(Datasource):
     """
     A SqlAlchemyDatasource will provide data_assets converting batch_kwargs using the following rules:
@@ -112,9 +131,7 @@ class SqlAlchemyDatasource(Datasource):
                 self.engine.connect()
             elif "url" in credentials:
                 url = credentials.pop("url")
-                # TODO perhaps we could carefully regex out the driver from the
-                #  url. It would need to be cautious to avoid leaking secrets.
-                self.drivername = "other"
+                self.drivername = urlparse(url).scheme
                 self.engine = create_engine(url, **kwargs)
                 self.engine.connect()
 
@@ -125,10 +142,26 @@ class SqlAlchemyDatasource(Datasource):
                 self.engine = create_engine(options)
                 self.engine.connect()
 
-        except (
-            sqlalchemy.exc.OperationalError,
-            sqlalchemy.exc.DatabaseError,
-        ) as sqlalchemy_error:
+            # since we switched to lazy loading of Datasources when we initialise a DataContext,
+            # the dialect of SQLAlchemy Datasources cannot be obtained reliably when we send
+            # "data_context.__init__" events.
+            # This event fills in the SQLAlchemy dialect.
+            if data_context is not None and getattr(
+                data_context, "_usage_statistics_handler", None
+            ):
+                handler = data_context._usage_statistics_handler
+                handler.send_usage_message(
+                    event="datasource.sqlalchemy.connect",
+                    event_payload={
+                        "anonymized_name": handler._datasource_anonymizer.anonymize(
+                            self.name
+                        ),
+                        "sqlalchemy_dialect": self.engine.name,
+                    },
+                    success=True,
+                )
+
+        except datasource_initialization_exceptions as sqlalchemy_error:
             raise DatasourceInitializationError(self._name, str(sqlalchemy_error))
 
         self._build_generators()
@@ -160,7 +193,11 @@ class SqlAlchemyDatasource(Datasource):
     def get_batch(self, batch_kwargs, batch_parameters=None):
         # We need to build a batch_id to be used in the dataframe
         batch_markers = BatchMarkers(
-            {"ge_load_time": datetime.datetime.utcnow().strftime("%Y%m%dT%H%M%S.%fZ")}
+            {
+                "ge_load_time": datetime.datetime.now(datetime.timezone.utc).strftime(
+                    "%Y%m%dT%H%M%S.%fZ"
+                )
+            }
         )
 
         if "bigquery_temp_table" in batch_kwargs:
